/******************************************************************************/
/* Files to Include                                                           */
/******************************************************************************/


#include <xc.h>         /* XC8 General Include File */


#include <stdint.h>        /* For uint8_t definition */
#include <stdbool.h>       /* For true/false definition */
#include <stdlib.h>        /* For rand */

#include "system.h"        /* System funct/params, like osc/periph eral config */
#include "user.h"          /* User funct/params, such as InitApp */



//  #include "config.h"
/******************************************************************************/
/* User Global Variable Declaration                                           */
/******************************************************************************/

int VariableTiming; // gets filled with random seconds between 3 and 6 [ms]//
void RunCountdown(void); // when receiving WRLS signal, start interrupt, start countdown.
void VariableDelay(int); // delay functions only accept constants, this is a delay loop to compensate.[deciseconds]//

/******************************************************************************/
/* Main Program                                                               */
/******************************************************************************/
void main(void)
{
    /* Configure the oscillator for the device */
    ConfigureOscillator();

    /* Initialize I/O and Peripherals for application */
    InitApp();
    
    PORTAbits.RA0 = 1;// Green power LED is constantly on when device is on //

    INTCONbits.INTF = 0;
    INTCONbits.INTE = 1;
    INTCONbits.GIE = 1;

    while (1){
        SLEEP();
    };
}

void VariableDelay(int deciSeconds)
{
    int loopCounter = 0;
    while (loopCounter < deciSeconds){
        _delay(100000);
        loopCounter++;
    }
}

void RunCountdown(void) // called upon by interrupt on RB4
{
    int blinkCounter = 0; //initialise the internal counter for the blinking light after PreVariable Timing//

    PORTAbits.RA1 = 1; //turn on red LED
    VariableDelay(PreVariableTiming); //First a known countdown (see user.h) to prepare for gate drop//
    while (blinkCounter<5) {
            PORTAbits.RA1 = 0;
            VariableDelay(BlinkingSpeedOff);
            PORTAbits.RA1 = 1;
            VariableDelay(BlinkingSpeedOn);
            blinkCounter++;
    }
    PORTAbits.RA1 = 0; // Turn off red light before last countdown, after buzzer//
    PORTAbits.RA4 = 1; // Turn on buzzer for a period of time//
    VariableDelay(BuzzerDuration);
    PORTAbits.RA4 = 0; // Turn buzzer back off//
    

    VariableTiming = rand() % 30 + 30; // is a pseudovariable timing of 3000 to 6000 milliseconds //
    VariableDelay(VariableTiming); //I think the TCY of the PIC16F84A is 1s//

    PORTBbits.RB4 = 1; // Drive the solenoid for a certain duration//
    VariableDelay(SolenoidDuration);
    PORTBbits.RB4 = 0; //Turn Solenoidoperation back off//
    
}



